import React, { useRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeCollapsible';
var CONTENT_CLASS = BASE_CLASS + "-content";
var CONTAINER_BUTTON_CLASS = BASE_CLASS + "-container";
var COLLAPSED_CLASS = 'is-collapsed';
var BUTTON_CLASS = BASE_CLASS + "-btn";
var BUTTON_CONTENT_CLASS = BUTTON_CLASS + "-content";
var ICON_CLASS = BASE_CLASS + "-icon";
var MIN_HEIGHT = 100; // px

var CONTENT_ALIGN = {
  CENTER: 'center',
  RIGHT: 'right'
};

var MoleculeCollapsible = function MoleculeCollapsible(_ref) {
  var _cx, _cx2, _cx3, _cx4;

  var _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
      _ref$onOpen = _ref.onOpen,
      onOpen = _ref$onOpen === void 0 ? function () {} : _ref$onOpen,
      alignContainer = _ref.alignContainer,
      children = _ref.children,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? MIN_HEIGHT : _ref$height,
      icon = _ref.icon,
      showText = _ref.showText,
      hideText = _ref.hideText,
      _ref$withGradient = _ref.withGradient,
      withGradient = _ref$withGradient === void 0 ? true : _ref$withGradient,
      _ref$withOverflow = _ref.withOverflow,
      withOverflow = _ref$withOverflow === void 0 ? false : _ref$withOverflow,
      _ref$withTransition = _ref.withTransition,
      withTransition = _ref$withTransition === void 0 ? true : _ref$withTransition;
  var childrenContainer = useRef();

  var _useState = useState(true),
      collapsed = _useState[0],
      setCollapsed = _useState[1];

  var _useState2 = useState(true),
      showButton = _useState2[0],
      setShowButton = _useState2[1];

  var _useState3 = useState(MIN_HEIGHT),
      maxHeight = _useState3[0],
      setMaxHeight = _useState3[1];

  var toggleCollapse = function toggleCollapse() {
    if (showButton) {
      setCollapsed(!collapsed);
      collapsed && onOpen() || onClose();
    }
  };

  useEffect(function () {
    var offsetHeight = childrenContainer.current.offsetHeight;
    setShowButton(offsetHeight >= height);
    setMaxHeight(offsetHeight);
  }, [height]);
  var wrapperClassName = cx("" + BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--withGradient"] = withGradient, _cx[COLLAPSED_CLASS] = collapsed, _cx));
  var iconClassName = cx("" + ICON_CLASS, (_cx2 = {}, _cx2[COLLAPSED_CLASS] = collapsed, _cx2));
  var containerClassName = cx("" + CONTAINER_BUTTON_CLASS, (_cx3 = {}, _cx3[CONTAINER_BUTTON_CLASS + "--withGradient"] = withGradient, _cx3[COLLAPSED_CLASS] = collapsed, _cx3[CONTAINER_BUTTON_CLASS + "--" + alignContainer] = alignContainer, _cx3));
  var contentClassName = cx("" + CONTENT_CLASS, (_cx4 = {}, _cx4[CONTENT_CLASS + "--withTransition"] = withTransition, _cx4[CONTENT_CLASS + "--withOverflow"] = withOverflow, _cx4));
  var containerHeight = showButton && collapsed ? height + "px" : maxHeight + "px";
  return /*#__PURE__*/React.createElement("div", {
    className: wrapperClassName
  }, /*#__PURE__*/React.createElement("div", {
    className: contentClassName,
    style: {
      maxHeight: "" + containerHeight
    }
  }, /*#__PURE__*/React.createElement("div", {
    ref: childrenContainer
  }, children)), showButton && /*#__PURE__*/React.createElement("div", {
    className: containerClassName
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: BUTTON_CLASS,
    onClick: toggleCollapse
  }, /*#__PURE__*/React.createElement("span", {
    className: BUTTON_CONTENT_CLASS,
    tabIndex: "-1"
  }, collapsed ? showText : hideText, /*#__PURE__*/React.createElement("span", {
    className: iconClassName
  }, icon)))));
};

MoleculeCollapsible.displayName = 'MoleculeCollapsible';
export default MoleculeCollapsible;
export { CONTENT_ALIGN };